@@ -24,14 +24,16 @@ pub use bitcoind;
 /// Electrs configuration parameters, implements a convenient [Default] for most common use.
 ///
 /// Default values:
-/// ```no_run
-/// electrsd::Conf {
-///     args: vec!["-vvv"],
-///     view_stderr: false,
-///     http_enabled: false,
-///     network: "regtest",
-/// };
 /// ```
+/// let mut conf = electrsd::Conf::default();
+/// conf.args = vec!["-vvv"];
+/// conf.view_stderr = false;
+/// conf.http_enabled = false;
+/// conf.network = "regtest";
+/// assert_eq!(conf, electrsd::Conf::default());
+/// ```
+#[derive(Debug, PartialEq)]
+#[non_exhaustive]
 pub struct Conf<'a> {
     /// Electrsd command line arguments
     /// note that `db-dir`, `cookie`, `cookie-file`, `daemon-rpc-addr`, `jsonrpc-import`, `electrum-rpc-addr`, `monitoring-addr`, `http-addr`  cannot be used cause they are automatically initialized.
@@ -155,7 +157,18 @@ impl ElectrsD {
         let rpc_socket = bitcoind.params.rpc_socket.to_string();
         args.push(&rpc_socket);
 
-        args.push("--jsonrpc-import");
+        let p2p_socket;
+        if cfg!(feature = "electrs_0_9_1") {
+            args.push("--daemon-p2p-addr");
+            p2p_socket = bitcoind
+                .params
+                .p2p_socket
+                .expect("electrs_0_9_1 requires bitcoind with p2p port open")
+                .to_string();
+            args.push(&p2p_socket);
+        } else {
+            args.push("--jsonrpc-import");
+        }
 
         let electrum_url = format!("0.0.0.0:{}", get_available_port()?);
         args.push("--electrum-rpc-addr");
@@ -251,11 +264,10 @@ impl From<nix::Error> for Error {
 
 /// Provide the electrs executable path if a version feature has been specified
 pub fn downloaded_exe_path() -> Option<String> {
-    // CARGO_HOME surely available only in `build.rs` here we need to get from home_dir
     if versions::HAS_FEATURE {
         Some(format!(
-            "{}/.cargo/electrs/{}/electrs",
-            dirs_next::home_dir()?.display(),
+            "{}/electrs/{}/electrs",
+            env!("OUT_DIR"),
             versions::electrs_name(),
         ))
     } else {
@@ -265,22 +277,26 @@ pub fn downloaded_exe_path() -> Option<String> {
 
 #[cfg(test)]
 mod test {
+    use crate::bitcoind::P2P;
     use crate::ElectrsD;
     use bitcoind::bitcoincore_rpc::RpcApi;
     use electrum_client::ElectrumApi;
+    use log::{debug, log_enabled, Level};
     use std::env;
 
     #[test]
     fn test_electrsd() {
         let (bitcoind_exe, electrs_exe) = init();
-        dbg!(&electrs_exe);
-        let conf = bitcoind::Conf {
-            view_stdout: true,
-            ..Default::default()
-        };
+        debug!("bitcoind: {}", &bitcoind_exe);
+        debug!("electrs: {}", &electrs_exe);
+        let mut conf = bitcoind::Conf::default();
+        conf.view_stdout = log_enabled!(Level::Debug);
+        if cfg!(feature = "electrs_0_9_1") {
+            conf.p2p = P2P::Yes;
+        }
         let bitcoind = bitcoind::BitcoinD::with_conf(&bitcoind_exe, &conf).unwrap();
         let electrs_conf = crate::Conf {
-            view_stderr: true,
+            view_stderr: log_enabled!(Level::Debug),
             ..Default::default()
         };
         let electrsd = ElectrsD::with_conf(&electrs_exe, &bitcoind, &electrs_conf).unwrap();
